@@ -6,7 +6,7 @@ BEGIN {
 }
 
 package Types::Bool;
-$Types::Bool::VERSION = '0.1.0'; # TRIAL
+
 # ABSTRACT: Booleans as objects for Perl
 
 use 5.005;
@@ -30,6 +30,9 @@ BEGIN {
         require Scalar::Util;
         *is_bool = sub ($) { Scalar::Util::blessed( $_[0] ) and $_[0]->isa('Types::Bool') };
     }
+
+    $Types::Bool::VERSION = '2.98001'
+      unless $Types::Bool::VERSION;
 }
 
 sub to_bool ($) { $_[0] ? true : false }
@@ -53,30 +56,3 @@ sub import {    # Load Exporter only if needed
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Types::Bool - Booleans as objects for Perl
-
-=head1 VERSION
-
-version 0.1.0
-
-=head1 AUTHOR
-
-Adriano Ferreira <ferreira@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2018 by Adriano Ferreira.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
